/* generalities */

@font-face {
	font-family: 'FontAwesome';
	src: url('../xstatic/fonts/fontawesome-webfont.eot?v=4.1.0');
	src: url('../xstatic/fonts/fontawesome-webfont.eot?#iefix&v=4.1.0') format('embedded-opentype'), url('../xstatic/fonts/fontawesome-webfont.woff?v=4.1.0') format('woff'), url('../xstatic/fonts/fontawesome-webfont.ttf?v=4.1.0') format('truetype'), url('../xstatic/fonts/fontawesome-webfont.svg?v=4.1.0#fontawesomeregular') format('svg');
	font-weight: normal;
	font-style: normal;
}

html, body {
	margin: 0;
	font-family: "Bitstream Vera Sans", "Verdana", sans-serif;
	background: #eee;
	color: #3c3c33;
}

html {
	min-height: 100%;
	position: relative;
}

body {
	height: 100%;
}

a {
	color: #0066cc;
	text-decoration: none;
	border-width: 0;
	border-bottom: 1px dotted #ff9900;
	-webkit-transition: color 200ms ease-out;
}

a:hover {
	color: #003388;
	border-style: solid;
}

a img {
	border: 0;
}

dl dt {
	margin : 0;
	padding : 0 0 0 0;
}

dl dd {
	margin : 0.3em 0 1.5em 10px;
}

span.error-message {
	color: #e00;
	font-weight: bold;
}

span.warning {
	background-color: orange;
}

.clear {
	clear: both;
}


/* from top to bottom */

/* top bar */

div#top {
	background: black;
	color: #eee;
	text-align: right;
	line-height: 200%;
	height: 2em;
}

div#top a {
	color: #aaa;
	font-weight: normal;
}

div#top a:hover {
	color: #888;
	border: 0;
}

ul.user-info {
	margin: 0;
	padding: 0;
	font-size: 85%;
	font-weight: bold;
}

ul.user-info li {
	display: inline;
	padding-left: 10px;
	padding-right: 3em;
}

ul.user-info a {
	border: none;
}

/* header */

div#header {
	background: #AD7C6D url(adwaita-lock.jpg);
	color: white;
	padding-left: 25px;
	border-bottom: 1px solid #888;
	position: relative;
	height: 5em;
}

div#header h1 {
	margin: 0;
	padding: 15px 0 25px 0;
	font-weight: normal;
	text-shadow: 0 2px 15px black;
}

/* notifications */

ul.messages {
	position: fixed;
	width: 30em;
	top: 8px;
	right: 10px;
	padding: 0;
	z-index: 2000;
	margin-top: 1em;
	list-style-type: none;
	margin: auto;
	background: #646464;
	background: rgba(40, 40, 40, 0.95);
	color: white;
	text-shadow: 1px 1px 1px black;
	border-radius: 10px;
	box-shadow: 0 0 4px black;
}

ul.messages li {
	padding: 1ex;
	margin: 1ex;
}

/* main content */

div#main-content {
	width: 95%;
	margin-left: 0;
	padding: 0 6px 0 16px;
	border: 1px solid #ccc;
	border-width: 0 1px 1px 0;
	background: white;
	float: left;
	position: relative;
	overflow-x: auto;
	overflow-y: hidden;
}

div#main-content h2 {
	font-weight: normal;
}

/* breadcrumb */

div#more-user-links {
	padding: 5px 0px;
	font-size: 110%;
}

div#more-user-links a,
div#more-user-links a:after {
	background: #ccc;
	text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
	border: 1px solid #bbb;
	transition: background 0.5s;
}

div#more-user-links a {
	box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
	padding: 4px 12px;
	border-radius: 2px;
	text-decoration: none;
	font-size: 90%;
	color: black;
}

span#breadcrumb {
	display: inline-block;
	margin: 1ex 0;
}

span#breadcrumb a {
	display: inline-block;
	padding-left: 20px;
	position: relative;
	height: 14px;
	margin-left: -4px;
}

span#breadcrumb a:first-child {
	margin-left: 0;
	padding-left: 16px;
}

span#breadcrumb a:after {
	content: "";
	height: 22px;
	width: 22px;
	-webkit-transform: scale(0.4, 0.707) rotate(45deg);
	-moz-transform: scale(0.4, 0.707) rotate(45deg);
	transform: scale(0.4, 0.707) rotate(45deg);
	display: inline-block;
	position: absolute;
	top: 0px;
	box-shadow: 1px -1px 0px 1px #bbb, 2px -2px 0px 2px white;
	z-index: 100;
	border-width: 1px 1px 0 0;
}

div#more-user-links a:hover,
div#more-user-links a:hover:after {
	text-decoration: underline;
	background: #aaa;
}

/* page content */

div#content {
	margin: 1em 1ex;
	padding: 7px;
	position: relative;
}

div#content h2 {
	margin-top: 0;
	font-weight: normal;
	color: #656551;
	font-size: 200%;
	letter-spacing: -1px;
	line-height: 25px;
	margin-bottom: 20px;
	padding: 0 0 10px 0px;
	position: relative;
	top: 4px;
	border-bottom: 1px dotted #d8d8d8;
}

div#appbar a {
	position: relative;
	top: -45px;
	float: right;
	margin-left: 2em;
}

table.main {
	width: 100%;
	border: 1px solid #bcbcbc;
	border-collapse: collapse;
}

table.main th {
	font-weight: normal;
	padding: 1em 1ex;
	border-bottom: 1px solid #bcbcbc;
	background: #FCFCFC;
}

table.main td {
	text-align: center;
	padding: 1em 1ex;
	border-bottom: 1px solid #bcbcbc;
}

table.main tr td.checkbox {
	width: 1em;
}

table.main tr:nth-child(odd) td {
}

table.main tr:hover td {
	background: #ccc;
	cursor: pointer;
}

table.main tr.active td {
	background: #bbf;
}


/* zone selection */

ul.apps {
	margin-top: 2em;
	margin-bottom: 2em;
}

ul.apps li {
	display: table;
	float: left;
	margin-right: 1em;
	margin-bottom: 1em;
}

ul.apps li a {
	background-color: transparent;
	background-repeat: no-repeat;
	background-position: 50% 50%;
	display: table-cell;
	vertical-align: bottom;
	width: 120px;
	height: 110px;
	padding-bottom: 10px;
	font-weight: bold;
	text-align: center;
	border: 1px dotted #666;
	text-decoration: none;
	transition: all .2s ease-in-out;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	color: #FF7800;
}

ul.apps li a:hover {
	border: 1px solid #333;
	color: #FF7800;
}

/* footer */

div#footer {
	clear: both;
	margin-left: 2%;
	font-size: 60%;
	width: 96%;
}

/* icons */

[class^="icon-"]:after, [class*=" icon-"]:after,
[class^="icon-"]:before, [class*=" icon-"]:before {
	font-family: FontAwesome;
	font-weight: normal;
	font-style: normal;
	display: inline-block;
	text-decoration: none;
}
a[class^="icon-"], a[class*=" icon-"] {
	display: inline-block;
	text-decoration: none;
	border: none;
	color: #FF7800;
}

.icon-home-space:before           { content: "\f015\00a0\00a0"; }
.icon-remove-sign:before          { content: "\f057"; }

/* misc */

div.bo-block {
	border: 1px solid #e4e4e4;
	background: #fcfcfc;
	color: #505050;
	margin: 1em;
	padding: 1ex;
}

div.bo-block h2 {
	margin: 0;
	border-bottom: 1px solid #bcbcbc;
	color: #474747;
}

div.dimmed-block h2 {
	color: #808080;
}

div.bo-block ul {
	padding-left: 2em;
	padding-bottom: 1ex;
}

div.big-msg-info {
	background: transparent url(../images/info-icon.png) 5px 5px no-repeat;
	width: 30em;
	padding-left: 90px;
	margin: 3em auto;
	min-height: 90px;
	padding-top: 20px;
}

p.paginator {
	margin: 4ex 0;
}

p.paginator *:first-child {
	border-radius: 3px 0 0 3px;
}

p.paginator *:last-child {
	border-radius: 0 3px 3px 0;
}

p.paginator a,
p.paginator span {
	padding: 1.5ex 1.7ex 1ex 1.7ex;
	border: 1px solid #BCBCBC;
	margin: 0 0 0 -1px;
}

p.paginator span.this-page {
	background: #0066CC;
	border-color: #0066CC;
	color: white;
}

p.paginator span.this-page + a {
	border-left-color: #0066CC;
}

p.paginator a:hover {
	background: #eee;
}

/* widgets & dialogs */

textarea:focus,
input[type="text"]:focus,
input[type="email"]:focus,
input[type="password"]:focus,
textarea,
input[type="text"],
input[type="email"],
input[type="password"] {
	border: 1px solid #bbb;
	padding: 7px 10px;
	background: white;
	color: black;
	box-shadow: inset 0 1px 3px #ddd;
}

textarea:focus,
input[type="text"]:focus,
input[type="email"]:focus,
input[type="password"]:focus {
	box-shadow: 0 0 0px 1px #1999cd;
}

textarea:focus,
input[type="text"]:focus,
input[type="email"]:focus,
input[type="password"]:focus {
	box-shadow: 0 0 0px 1px #1999cd;
}

button::-moz-focus-inner {
	border: 0;
	padding: 1px 0 -1px 0;
	margin: -3px 0 1px 0;
}

a.button, button, input[type=submit] {
	line-height: 100%;
	cursor: pointer;
	border: 1px solid #b7b7b7;
	border-radius: 1px;
	color: #424258;
	padding: 1ex 2ex;
	text-decoration: none;
	background: #aaaaaa;
	background-image: linear-gradient(to bottom, #f9f9f9, #eeeeee);
	box-shadow: 0 2px 2px 0px #ddd;
}

a.button {
	padding-bottom: calc(1ex + 1px);
}

input[type="submit"][name="submit"] {
	background: #283c54;
	background-image: linear-gradient(to bottom, #1cabe7, #1999cd);
	color: white;
	border-color: #267dae;
}

input[type=submit]:hover {
	border-color: #666;
}

/* disabled items */
textarea.disabled:focus,
input.disabled[type="text"]:focus,
input.disabled[type="email"]:focus,
input.disabled[type="password"]:focus,
textarea.disabled,
input.disabled[type="text"],
input.disabled[type="email"],
input.disabled[type="password"],
textarea.disabled:focus,
input.disabled[type="text"]:focus,
input.disabled[type="email"]:focus,
input.disabled[type="password"]:focus,
a.button.disabled, button.disabled, button[disabled] {
	border: 1px solid #bbb;
	background: #f9f9f9;
	cursor: default;
	box-shadow: none;
	color: #888;
}

a.disabled {
	color: #888;
	text-decoration: none;
	border: none;
	cursor: default;
}

/* dialog styling */

.ui-dialog .ui-widget-content .ui-state-default.ui-button {
	border-radius: 1px;
	background: #e6e6e6;
	box-shadow: 0px 0px 2px 0px #DDD;
}

.ui-dialog .ui-widget-content .ui-state-default:hover {
	border-color: #ccc;
	box-shadow: 0px 0px 2px 0px #bbb;
}

.ui-dialog .ui-widget-content .ui-state-default.delete-button {
	background: #bc4c38;
	background-image: linear-gradient(to bottom, #dc2c18, #a43c28);
	color: white;
	font-weight: bold;
}

.ui-dialog .ui-widget-content .ui-state-default.delete-button:hover {
	border-color: #a43c28;
}

.ui-dialog .ui-widget-content .ui-state-default.submit-button {
	background: #283c54;
	background-image: linear-gradient(to bottom, #1cabe7, #1999cd);
	color: white;
	font-weight: bold;
}

.ui-dialog .ui-widget-content .ui-state-default.submit-button:hover {
	border-color: #283c94;
}

div.ui-widget-overlay {
	background: #333;
}

div.ui-dialog {
	border: 0;
	box-shadow: rgb(102, 102, 102) 0px 0px 20px 2px;
	padding: 0;
	border-radius: 0;
	max-width: 80%;
	min-width: 30%;
}

div.ui-dialog .ui-dialog-titlebar {
	background: #eee;
	border-radius: 0;
	border: none;
}

div.ui-dialog .ui-dialog-titlebar .ui-dialog-title {
	font-size: 130%;
	font-weight: normal;
}

div.ui-dialog .ui-dialog-titlebar button {
	border: transparent;
	background: transparent;
	box-shadow: none;
}

div.ui-dialog form p input,
div.ui-dialog form p select,
div.ui-dialog form p textarea {
	width: 95%;
}

div.ui-dialog form p input[type=checkbox] {
	width: auto;
}

form p {
	margin: 0 0 1em 0;
}

form p label {
	display: block;
}

form p.required label:after {
	padding-left: 1ex;
	content: "*";
	color: red;
}

form p label {
	margin-bottom: 0.5ex;
}

ul.errorlist {
	margin: 0;
	padding: 0;
	color: #e80404;
	list-style: none;
}

form.small p input {
	margin-left: 0;
}

form.small p {
	margin-bottom: 0.5em;
}

form.small label {
	width: 200px;
	display: inline-block;
}

form.small a.button,
form.small button {
	margin-left: 205px;
	display: inline-block;
}

form.small button + button,
form.small button + a.button {
	margin-left: 1em;
}

#sidepage {
	position: absolute;
	z-index: 100;
	width: 30ex;
	height: 2em;
	text-align: left;
	transition: all 0ms ease-in;
	overflow: hidden;
}

#main.sidepage-expanded {
	margin-left: 30ex;
}

#main.enable-transitions,
#sidepage.enable-transitions ul#sidepage-menu,
#sidepage.enable-transitions {
	transition-duration: 400ms;
}

#sidepage.sidepage-expanded {
	height: 100%;
	overflow: initial;
}

#sidepage.sidepage-expanded ul#sidepage-menu {
	transform: scale(1);
}

#main {
	transition: margin-left 0ms ease-in;
}

#sidepage span#applabel {
	padding-left: 1em;
	font-weight: bold;
	cursor: pointer;
	display: block;
	background: black;
}

#sidepage ul#sidepage-menu {
	list-style: none;
	padding: 0;
	padding-top: 1em;
	margin: 0;
	background: #23282d url(texture.png);
	height: 100%;
	height: calc(100% - 3em); /* #top 2em, padding-top: 1em */
	transition: all 0ms ease;
	transform: scale(1, 0);
	transform-origin: 0 0;
}

#sidepage ul#sidepage-menu a {
	border: none;
	display: block;
}

#sidepage ul#sidepage-menu li {
	padding-left: 1em;
	position: relative;
	line-height: 24px;
}

ul#sidepage-menu li a {
	background: transparent no-repeat 0 50%;
	padding: 5px 0 5px 25px;
}

#sidepage ul#sidepage-menu .active a {
	color: #eee;
}

#sidepage ul#sidepage-menu li.active,
#sidepage ul#sidepage-menu li.active:hover {
	background: #215D9C;
}

#sidepage ul#sidepage-menu li:hover {
	background: rgba(0, 0, 0, 0.3);
}


#sidepage ul#sidepage-menu li.active:after {
	content: "";
	position: absolute;
	display: block;
	top: 0;
	background: #215D9C;
	right: -17px;
	width: 34px;
	height: 34px;
	-moz-transform: scale(0.4, 0.707) rotate(45deg);
	-webkit-transform: scale(0.4, 0.707) rotate(45deg);
	transform: scale(0.4, 0.707) rotate(45deg);
}

#gadjo-ajax-error {
	position: fixed;
	right: 1em;
	bottom: 1em;
	max-width: 30em;
	background: rgb(255, 34, 34) none repeat scroll 0% 0%;
	padding: 1ex;
	font-weight: bold;
	color: white;
	border: 1px solid red;
	box-shadow: 0px 0px 4px red;
	border-radius: 2px;
}

ul#sidepage-menu li a.icon-add { background-image: url(icons/add.small.png); }
ul#sidepage-menu li a.icon-calendar { background-image: url(icons/calendar.small.png); }
ul#sidepage-menu li a.icon-categories { background-image: url(icons/categories.small.png); }
ul#sidepage-menu li a.icon-clock { background-image: url(icons/clock.small.png); }
ul#sidepage-menu li a.icon-connector { background-image: url(icons/connector.small.png); }
ul#sidepage-menu li a.icon-facturier { background-image: url(icons/facturier.small.png); }
ul#sidepage-menu li a.icon-forms { background-image: url(icons/forms.small.png); }
ul#sidepage-menu li a.icon-gis { background-image: url(icons/gis.small.png); }
ul#sidepage-menu li a.icon-grid { background-image: url(icons/grid.small.png); }
ul#sidepage-menu li a.icon-home { background-image: url(icons/home.small.png); }
ul#sidepage-menu li a.icon-management { background-image: url(icons/management.small.png); }
ul#sidepage-menu li a.icon-organizational-units { background-image: url(icons/organizational-units.small.png); }
ul#sidepage-menu li a.icon-password { background-image: url(icons/password.small.png); }
ul#sidepage-menu li a.icon-phone { background-image: url(icons/phone.small.png); }
ul#sidepage-menu li a.icon-portal { background-image: url(icons/portal.small.png); }
ul#sidepage-menu li a.icon-porte-doc { background-image: url(icons/porte-doc.small.png); }
ul#sidepage-menu li a.icon-roles { background-image: url(icons/roles.small.png); }
ul#sidepage-menu li a.icon-security { background-image: url(icons/security.small.png); }
ul#sidepage-menu li a.icon-services { background-image: url(icons/services.small.png); }
ul#sidepage-menu li a.icon-settings { background-image: url(icons/settings.small.png); }
ul#sidepage-menu li a.icon-submission { background-image: url(icons/submission.small.png); }
ul#sidepage-menu li a.icon-users { background-image: url(icons/users.small.png); }
ul#sidepage-menu li a.icon-workflows { background-image: url(icons/workflows.small.png); }
ul.apps li.icon-add a { background-image: url(icons/add.large.png); }
ul.apps li.icon-add a:hover { background-image: url(icons/add.large-hover.png); }
ul.apps li.icon-calendar a { background-image: url(icons/calendar.large.png); }
ul.apps li.icon-calendar a:hover { background-image: url(icons/calendar.large-hover.png); }
ul.apps li.icon-categories a { background-image: url(icons/categories.large.png); }
ul.apps li.icon-categories a:hover { background-image: url(icons/categories.large-hover.png); }
ul.apps li.icon-clock a { background-image: url(icons/clock.large.png); }
ul.apps li.icon-clock a:hover { background-image: url(icons/clock.large-hover.png); }
ul.apps li.icon-connector a { background-image: url(icons/connector.large.png); }
ul.apps li.icon-connector a:hover { background-image: url(icons/connector.large-hover.png); }
ul.apps li.icon-facturier a { background-image: url(icons/facturier.large.png); }
ul.apps li.icon-facturier a:hover { background-image: url(icons/facturier.large-hover.png); }
ul.apps li.icon-forms a { background-image: url(icons/forms.large.png); }
ul.apps li.icon-forms a:hover { background-image: url(icons/forms.large-hover.png); }
ul.apps li.icon-gis a { background-image: url(icons/gis.large.png); }
ul.apps li.icon-gis a:hover { background-image: url(icons/gis.large-hover.png); }
ul.apps li.icon-grid a { background-image: url(icons/grid.large.png); }
ul.apps li.icon-grid a:hover { background-image: url(icons/grid.large-hover.png); }
ul.apps li.icon-home a { background-image: url(icons/home.large.png); }
ul.apps li.icon-home a:hover { background-image: url(icons/home.large-hover.png); }
ul.apps li.icon-management a { background-image: url(icons/management.large.png); }
ul.apps li.icon-management a:hover { background-image: url(icons/management.large-hover.png); }
ul.apps li.icon-organizational-units a { background-image: url(icons/organizational-units.large.png); }
ul.apps li.icon-organizational-units a:hover { background-image: url(icons/organizational-units.large-hover.png); }
ul.apps li.icon-password a { background-image: url(icons/password.large.png); }
ul.apps li.icon-password a:hover { background-image: url(icons/password.large-hover.png); }
ul.apps li.icon-phone a { background-image: url(icons/phone.large.png); }
ul.apps li.icon-phone a:hover { background-image: url(icons/phone.large-hover.png); }
ul.apps li.icon-portal a { background-image: url(icons/portal.large.png); }
ul.apps li.icon-portal a:hover { background-image: url(icons/portal.large-hover.png); }
ul.apps li.icon-porte-doc a { background-image: url(icons/porte-doc.large.png); }
ul.apps li.icon-porte-doc a:hover { background-image: url(icons/porte-doc.large-hover.png); }
ul.apps li.icon-roles a { background-image: url(icons/roles.large.png); }
ul.apps li.icon-roles a:hover { background-image: url(icons/roles.large-hover.png); }
ul.apps li.icon-security a { background-image: url(icons/security.large.png); }
ul.apps li.icon-security a:hover { background-image: url(icons/security.large-hover.png); }
ul.apps li.icon-services a { background-image: url(icons/services.large.png); }
ul.apps li.icon-services a:hover { background-image: url(icons/services.large-hover.png); }
ul.apps li.icon-settings a { background-image: url(icons/settings.large.png); }
ul.apps li.icon-settings a:hover { background-image: url(icons/settings.large-hover.png); }
ul.apps li.icon-submission a { background-image: url(icons/submission.large.png); }
ul.apps li.icon-submission a:hover { background-image: url(icons/submission.large-hover.png); }
ul.apps li.icon-users a { background-image: url(icons/users.large.png); }
ul.apps li.icon-users a:hover { background-image: url(icons/users.large-hover.png); }
ul.apps li.icon-workflows a { background-image: url(icons/workflows.large.png); }
ul.apps li.icon-workflows a:hover { background-image: url(icons/workflows.large-hover.png); }
